abstractmanytooneeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# abstractmanytooneeditor

class `camelot.view.controls.editors.abstractmanytooneeditor.` `AbstractManyToOneEditor`

  Helper functions for implementing a ManyToOneEditor, to be used in the ManyToOneEditor and in the ManyToManyEditor

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus